/*******************************************************************************
* File Name: EC_EEPROM_PM.c
* Version 1.80
*
* Description:
*  This file contains the API for the proper switching to/from the low power
*  modes.
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "EC_EEPROM.h"

/*  Function Prototypes */
void    EC_EEPROM_Enable(void);

#if(CY_PSOC5A)
    
    EC_EEPROM_BACKUP_STRUCT  EC_EEPROM_backup =
    {
        /* Enable state - disabled */
        EC_EEPROM_DISABLED,

        /* xcfg: enabled hardware addr detection */
        EC_EEPROM_XCFG_HDWR_ADDR_EN,

        /* addr: default address (0x04) */
        EC_EEPROM_DEFAULT_ADDR1,

        /* cfg: fast mode clock rate */
        EC_EEPROM_CFG_CLK_RATE_400,

        /* clkDiv: set CLK divider to 16 */
        EC_EEPROM_CLK_DIV_16
    };

#else

    EC_EEPROM_BACKUP_STRUCT  EC_EEPROM_backup =
    {
        /* enable state - disabled */
        EC_EEPROM_DISABLED,

        /* xcfg: wakeup disabled, enabled hardware addr detection */
        EC_EEPROM_XCFG_HDWR_ADDR_EN,

        /* addr: default address (0x04) */
        EC_EEPROM_DEFAULT_ADDR1,

        /* cfg: default bus speed - 100kHz, so write 0 (16 samples/bit) */
        0x00u,

        /* clkDiv1 */
        LO8(BCLK__BUS_CLK__KHZ / EC_EEPROM_BUS_SPEED),

        /* clkDiv2 */
        HI8(BCLK__BUS_CLK__KHZ / EC_EEPROM_BUS_SPEED)
    };        

#endif /* (CY_PSOC5A) */


/*******************************************************************************
* Function Name: EC_EEPROM_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the EZI2C component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  EC_EEPROM_backup - the non retention registers are saved to.
*
* Reentrant:
*  No
*
*******************************************************************************/
void EC_EEPROM_SaveConfig(void) 
{
    EC_EEPROM_backup.xcfg = EC_EEPROM_XCFG_REG;
    EC_EEPROM_backup.adr  = EC_EEPROM_ADDR_REG;
    EC_EEPROM_backup.cfg  = EC_EEPROM_CFG_REG;

    #if(CY_PSOC5A)
        EC_EEPROM_backup.clkDiv  = EC_EEPROM_CLKDIV_REG;
    #else
        EC_EEPROM_backup.clkDiv1  = EC_EEPROM_CLKDIV1_REG;
        EC_EEPROM_backup.clkDiv2  = EC_EEPROM_CLKDIV2_REG;
    #endif  /* (CY_PSOC5A) */
}


/*******************************************************************************
* Function Name: EC_EEPROM_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the previously saved by EC_EEPROM_SaveConfig() or 
*  EC_EEPROM_Sleep() configuration of the EZI2C component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  EC_EEPROM_backup - the non retention registers are restored from.
*
* Reentrant:
*  No
*
* Side Effects:
*  Calling this function before EC_EEPROM_SaveConfig() or
*  EC_EEPROM_Sleep() will lead to unpredictable results.
*
*******************************************************************************/
void EC_EEPROM_RestoreConfig(void) 
{
    /* There are master's configuration bits here */
    EC_EEPROM_CFG_REG |= (EC_EEPROM_backup.cfg & EC_EEPROM_I2C_MASTER_MASK);    
    
    EC_EEPROM_XCFG_REG = EC_EEPROM_backup.xcfg;
    EC_EEPROM_ADDR_REG = EC_EEPROM_backup.adr;

    #if(CY_PSOC5A)
        EC_EEPROM_CLKDIV_REG =EC_EEPROM_backup.clkDiv;
    #else
        EC_EEPROM_CLKDIV1_REG = EC_EEPROM_backup.clkDiv1;
        EC_EEPROM_CLKDIV2_REG = EC_EEPROM_backup.clkDiv2;
    #endif  /* (CY_PSOC5A) */
}


/*******************************************************************************
* Function Name: EC_EEPROM_Sleep
********************************************************************************
*
* Summary:
*  Saves component enable state and configuration. Stops component operation.
*  Should be called just prior to entering sleep. If "Enable wakeup from the
*  Sleep mode" is properly configured and enabled, this function should not be
*  called.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  EC_EEPROM_backup - the non retention registers are saved to. Changed
*  by EC_EEPROM_SaveConfig() function call.
*
* Reentrant:
*  No
*
*******************************************************************************/
void EC_EEPROM_Sleep(void) 
{
    if(EC_EEPROM_IS_BIT_SET(EC_EEPROM_PM_ACT_CFG_REG, EC_EEPROM_ACT_PWR_EN))
    {
        EC_EEPROM_backup.enableState = EC_EEPROM_ENABLED;
    }
    else /* The I2C block's slave is disabled */
    {
        EC_EEPROM_backup.enableState = EC_EEPROM_DISABLED;
    }
    
    /* Stop component */
    EC_EEPROM_Stop();

    /* Save registers configuration */
    EC_EEPROM_SaveConfig();
}


/*******************************************************************************
* Function Name: EC_EEPROM_Wakeup
********************************************************************************
*
* Summary:
*  Restores component enable state and configuration. Should be called
*  just after awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  EC_EEPROM_backup - the non retention registers are restored from.
*
* Reentrant:
*  No
*
* Side Effects:
*  Calling this function before EC_EEPROM_SaveConfig() or
*  EC_EEPROM_Sleep() will lead to unpredictable results.
*
*******************************************************************************/
void EC_EEPROM_Wakeup(void) 
{
    /* Restore registers values */
    EC_EEPROM_RestoreConfig();
    
    if(EC_EEPROM_ENABLED == EC_EEPROM_backup.enableState)
    {
        /* Enable component's operation */
        EC_EEPROM_Enable();

    } /* Do nothing if component's block was disabled before */
}


/* [] END OF FILE */
