/*******************************************************************************
* File Name: EC_SPI.h
* Version 2.40
*
* Description:
*  Contains the function prototypes, constants and register definition
*  of the SPI Master Component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SPIM_EC_SPI_H)
#define CY_SPIM_EC_SPI_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"

/* Check to see if required defines such as CY_PSOC5A are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5A)
    #error Component SPI_Master_v2_40 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5A) */


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define EC_SPI_INTERNAL_CLOCK             (0u)

#if(0u != EC_SPI_INTERNAL_CLOCK)
    #include "EC_SPI_IntClock.h"
#endif /* (0u != EC_SPI_INTERNAL_CLOCK) */

#define EC_SPI_MODE                       (1u)
#define EC_SPI_DATA_WIDTH                 (8u)
#define EC_SPI_MODE_USE_ZERO              (1u)
#define EC_SPI_BIDIRECTIONAL_MODE         (0u)

/* Internal interrupt handling */
#define EC_SPI_TX_BUFFER_SIZE             (4u)
#define EC_SPI_RX_BUFFER_SIZE             (4u)
#define EC_SPI_INTERNAL_TX_INT_ENABLED    (0u)
#define EC_SPI_INTERNAL_RX_INT_ENABLED    (0u)

#define EC_SPI_SINGLE_REG_SIZE            (8u)
#define EC_SPI_USE_SECOND_DATAPATH        (EC_SPI_DATA_WIDTH > EC_SPI_SINGLE_REG_SIZE)

#define EC_SPI_FIFO_SIZE                  (4u)
#define EC_SPI_TX_SOFTWARE_BUF_ENABLED    ((0u != EC_SPI_INTERNAL_TX_INT_ENABLED) && \
                                                     (EC_SPI_TX_BUFFER_SIZE > EC_SPI_FIFO_SIZE))

#define EC_SPI_RX_SOFTWARE_BUF_ENABLED    ((0u != EC_SPI_INTERNAL_RX_INT_ENABLED) && \
                                                     (EC_SPI_RX_BUFFER_SIZE > EC_SPI_FIFO_SIZE))


/***************************************
*        Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct
{
    uint8 enableState;
    uint8 cntrPeriod;
    #if(CY_UDB_V0)
        uint8 saveSrTxIntMask;
        uint8 saveSrRxIntMask;
    #endif /* (CY_UDB_V0) */

} EC_SPI_BACKUP_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

void  EC_SPI_Init(void)                           ;
void  EC_SPI_Enable(void)                         ;
void  EC_SPI_Start(void)                          ;
void  EC_SPI_Stop(void)                           ;

void  EC_SPI_EnableTxInt(void)                    ;
void  EC_SPI_EnableRxInt(void)                    ;
void  EC_SPI_DisableTxInt(void)                   ;
void  EC_SPI_DisableRxInt(void)                   ;

void  EC_SPI_Sleep(void)                          ;
void  EC_SPI_Wakeup(void)                         ;
void  EC_SPI_SaveConfig(void)                     ;
void  EC_SPI_RestoreConfig(void)                  ;

void  EC_SPI_SetTxInterruptMode(uint8 intSrc)     ;
void  EC_SPI_SetRxInterruptMode(uint8 intSrc)     ;
uint8 EC_SPI_ReadTxStatus(void)                   ;
uint8 EC_SPI_ReadRxStatus(void)                   ;
void  EC_SPI_WriteTxData(uint8 txData)  \
                                                            ;
uint8 EC_SPI_ReadRxData(void) \
                                                            ;
uint8 EC_SPI_GetRxBufferSize(void)                ;
uint8 EC_SPI_GetTxBufferSize(void)                ;
void  EC_SPI_ClearRxBuffer(void)                  ;
void  EC_SPI_ClearTxBuffer(void)                  ;
void  EC_SPI_ClearFIFO(void)                              ;
void  EC_SPI_PutArray(const uint8 buffer[], uint8 byteCount) \
                                                            ;

#if(0u != EC_SPI_BIDIRECTIONAL_MODE)
    void  EC_SPI_TxEnable(void)                   ;
    void  EC_SPI_TxDisable(void)                  ;
#endif /* (0u != EC_SPI_BIDIRECTIONAL_MODE) */

CY_ISR_PROTO(EC_SPI_TX_ISR);
CY_ISR_PROTO(EC_SPI_RX_ISR);


/**********************************
*   Variable with external linkage
**********************************/

extern uint8 EC_SPI_initVar;


/***************************************
*           API Constants
***************************************/

#define EC_SPI_TX_ISR_NUMBER     ((uint8) (EC_SPI_TxInternalInterrupt__INTC_NUMBER))
#define EC_SPI_RX_ISR_NUMBER     ((uint8) (EC_SPI_RxInternalInterrupt__INTC_NUMBER))

#define EC_SPI_TX_ISR_PRIORITY   ((uint8) (EC_SPI_TxInternalInterrupt__INTC_PRIOR_NUM))
#define EC_SPI_RX_ISR_PRIORITY   ((uint8) (EC_SPI_RxInternalInterrupt__INTC_PRIOR_NUM))


/***************************************
*    Initial Parameter Constants
***************************************/

#define EC_SPI_INT_ON_SPI_DONE    ((uint8) (0u   << EC_SPI_STS_SPI_DONE_SHIFT))
#define EC_SPI_INT_ON_TX_EMPTY    ((uint8) (0u   << EC_SPI_STS_TX_FIFO_EMPTY_SHIFT))
#define EC_SPI_INT_ON_TX_NOT_FULL ((uint8) (1u << \
                                                                           EC_SPI_STS_TX_FIFO_NOT_FULL_SHIFT))
#define EC_SPI_INT_ON_BYTE_COMP   ((uint8) (0u  << EC_SPI_STS_BYTE_COMPLETE_SHIFT))
#define EC_SPI_INT_ON_SPI_IDLE    ((uint8) (0u   << EC_SPI_STS_SPI_IDLE_SHIFT))

/* Disable TX_NOT_FULL if software buffer is used */
#define EC_SPI_INT_ON_TX_NOT_FULL_DEF ((EC_SPI_TX_SOFTWARE_BUF_ENABLED) ? \
                                                                        (0u) : (EC_SPI_INT_ON_TX_NOT_FULL))

/* TX interrupt mask */
#define EC_SPI_TX_INIT_INTERRUPTS_MASK    (EC_SPI_INT_ON_SPI_DONE  | \
                                                     EC_SPI_INT_ON_TX_EMPTY  | \
                                                     EC_SPI_INT_ON_TX_NOT_FULL_DEF | \
                                                     EC_SPI_INT_ON_BYTE_COMP | \
                                                     EC_SPI_INT_ON_SPI_IDLE)

#define EC_SPI_INT_ON_RX_FULL         ((uint8) (0u << \
                                                                          EC_SPI_STS_RX_FIFO_FULL_SHIFT))
#define EC_SPI_INT_ON_RX_NOT_EMPTY    ((uint8) (1u << \
                                                                          EC_SPI_STS_RX_FIFO_NOT_EMPTY_SHIFT))
#define EC_SPI_INT_ON_RX_OVER         ((uint8) (0u << \
                                                                          EC_SPI_STS_RX_FIFO_OVERRUN_SHIFT))

/* RX interrupt mask */
#define EC_SPI_RX_INIT_INTERRUPTS_MASK    (EC_SPI_INT_ON_RX_FULL      | \
                                                     EC_SPI_INT_ON_RX_NOT_EMPTY | \
                                                     EC_SPI_INT_ON_RX_OVER)
/* Nubmer of bits to receive/transmit */
#define EC_SPI_BITCTR_INIT            (((uint8) (EC_SPI_DATA_WIDTH << 1u)) - 1u)


/***************************************
*             Registers
***************************************/

#if(CY_PSOC3 || CY_PSOC5)
    #define EC_SPI_TXDATA_REG (* (reg8 *) \
                                                EC_SPI_BSPIM_sR8_Dp_u0__F0_REG)
    #define EC_SPI_TXDATA_PTR (  (reg8 *) \
                                                EC_SPI_BSPIM_sR8_Dp_u0__F0_REG)
    #define EC_SPI_RXDATA_REG (* (reg8 *) \
                                                EC_SPI_BSPIM_sR8_Dp_u0__F1_REG)
    #define EC_SPI_RXDATA_PTR (  (reg8 *) \
                                                EC_SPI_BSPIM_sR8_Dp_u0__F1_REG)
#else   /* PSOC4 */
    #if(EC_SPI_USE_SECOND_DATAPATH)
        #define EC_SPI_TXDATA_REG (* (reg16 *) \
                                          EC_SPI_BSPIM_sR8_Dp_u0__16BIT_F0_REG)
        #define EC_SPI_TXDATA_PTR (  (reg16 *) \
                                          EC_SPI_BSPIM_sR8_Dp_u0__16BIT_F0_REG)
        #define EC_SPI_RXDATA_REG (* (reg16 *) \
                                          EC_SPI_BSPIM_sR8_Dp_u0__16BIT_F1_REG)
        #define EC_SPI_RXDATA_PTR         (  (reg16 *) \
                                          EC_SPI_BSPIM_sR8_Dp_u0__16BIT_F1_REG)
    #else
        #define EC_SPI_TXDATA_REG (* (reg8 *) \
                                                EC_SPI_BSPIM_sR8_Dp_u0__F0_REG)
        #define EC_SPI_TXDATA_PTR (  (reg8 *) \
                                                EC_SPI_BSPIM_sR8_Dp_u0__F0_REG)
        #define EC_SPI_RXDATA_REG (* (reg8 *) \
                                                EC_SPI_BSPIM_sR8_Dp_u0__F1_REG)
        #define EC_SPI_RXDATA_PTR (  (reg8 *) \
                                                EC_SPI_BSPIM_sR8_Dp_u0__F1_REG)
    #endif /* (EC_SPI_USE_SECOND_DATAPATH) */
#endif     /* (CY_PSOC3 || CY_PSOC5) */

#define EC_SPI_AUX_CONTROL_DP0_REG (* (reg8 *) \
                                        EC_SPI_BSPIM_sR8_Dp_u0__DP_AUX_CTL_REG)
#define EC_SPI_AUX_CONTROL_DP0_PTR (  (reg8 *) \
                                        EC_SPI_BSPIM_sR8_Dp_u0__DP_AUX_CTL_REG)

#if(EC_SPI_USE_SECOND_DATAPATH)
    #define EC_SPI_AUX_CONTROL_DP1_REG  (* (reg8 *) \
                                        EC_SPI_BSPIM_sR8_Dp_u1__DP_AUX_CTL_REG)
    #define EC_SPI_AUX_CONTROL_DP1_PTR  (  (reg8 *) \
                                        EC_SPI_BSPIM_sR8_Dp_u1__DP_AUX_CTL_REG)
#endif /* (EC_SPI_USE_SECOND_DATAPATH) */

#define EC_SPI_COUNTER_PERIOD_REG     (* (reg8 *) EC_SPI_BSPIM_BitCounter__PERIOD_REG)
#define EC_SPI_COUNTER_PERIOD_PTR     (  (reg8 *) EC_SPI_BSPIM_BitCounter__PERIOD_REG)
#define EC_SPI_COUNTER_CONTROL_REG    (* (reg8 *) EC_SPI_BSPIM_BitCounter__CONTROL_AUX_CTL_REG)
#define EC_SPI_COUNTER_CONTROL_PTR    (  (reg8 *) EC_SPI_BSPIM_BitCounter__CONTROL_AUX_CTL_REG)

#define EC_SPI_TX_STATUS_REG          (* (reg8 *) EC_SPI_BSPIM_TxStsReg__STATUS_REG)
#define EC_SPI_TX_STATUS_PTR          (  (reg8 *) EC_SPI_BSPIM_TxStsReg__STATUS_REG)
#define EC_SPI_RX_STATUS_REG          (* (reg8 *) EC_SPI_BSPIM_RxStsReg__STATUS_REG)
#define EC_SPI_RX_STATUS_PTR          (  (reg8 *) EC_SPI_BSPIM_RxStsReg__STATUS_REG)

#define EC_SPI_CONTROL_REG            (* (reg8 *) \
                                      EC_SPI_BSPIM_BidirMode_SyncCtl_CtrlReg__CONTROL_REG)
#define EC_SPI_CONTROL_PTR            (  (reg8 *) \
                                      EC_SPI_BSPIM_BidirMode_SyncCtl_CtrlReg__CONTROL_REG)

#define EC_SPI_TX_STATUS_MASK_REG     (* (reg8 *) EC_SPI_BSPIM_TxStsReg__MASK_REG)
#define EC_SPI_TX_STATUS_MASK_PTR     (  (reg8 *) EC_SPI_BSPIM_TxStsReg__MASK_REG)
#define EC_SPI_RX_STATUS_MASK_REG     (* (reg8 *) EC_SPI_BSPIM_RxStsReg__MASK_REG)
#define EC_SPI_RX_STATUS_MASK_PTR     (  (reg8 *) EC_SPI_BSPIM_RxStsReg__MASK_REG)

#define EC_SPI_TX_STATUS_ACTL_REG     (* (reg8 *) EC_SPI_BSPIM_TxStsReg__STATUS_AUX_CTL_REG)
#define EC_SPI_TX_STATUS_ACTL_PTR     (  (reg8 *) EC_SPI_BSPIM_TxStsReg__STATUS_AUX_CTL_REG)
#define EC_SPI_RX_STATUS_ACTL_REG     (* (reg8 *) EC_SPI_BSPIM_RxStsReg__STATUS_AUX_CTL_REG)
#define EC_SPI_RX_STATUS_ACTL_PTR     (  (reg8 *) EC_SPI_BSPIM_RxStsReg__STATUS_AUX_CTL_REG)

#if(EC_SPI_USE_SECOND_DATAPATH)
    #define EC_SPI_AUX_CONTROLDP1     (EC_SPI_AUX_CONTROL_DP1_REG)
#endif /* (EC_SPI_USE_SECOND_DATAPATH) */


/***************************************
*       Register Constants
***************************************/

/* Status Register Definitions */
#define EC_SPI_STS_SPI_DONE_SHIFT             (0x00u)
#define EC_SPI_STS_TX_FIFO_EMPTY_SHIFT        (0x01u)
#define EC_SPI_STS_TX_FIFO_NOT_FULL_SHIFT     (0x02u)
#define EC_SPI_STS_BYTE_COMPLETE_SHIFT        (0x03u)
#define EC_SPI_STS_SPI_IDLE_SHIFT             (0x04u)
#define EC_SPI_STS_RX_FIFO_FULL_SHIFT         (0x04u)
#define EC_SPI_STS_RX_FIFO_NOT_EMPTY_SHIFT    (0x05u)
#define EC_SPI_STS_RX_FIFO_OVERRUN_SHIFT      (0x06u)

#define EC_SPI_STS_SPI_DONE           ((uint8) (0x01u << EC_SPI_STS_SPI_DONE_SHIFT))
#define EC_SPI_STS_TX_FIFO_EMPTY      ((uint8) (0x01u << EC_SPI_STS_TX_FIFO_EMPTY_SHIFT))
#define EC_SPI_STS_TX_FIFO_NOT_FULL   ((uint8) (0x01u << EC_SPI_STS_TX_FIFO_NOT_FULL_SHIFT))
#define EC_SPI_STS_BYTE_COMPLETE      ((uint8) (0x01u << EC_SPI_STS_BYTE_COMPLETE_SHIFT))
#define EC_SPI_STS_SPI_IDLE           ((uint8) (0x01u << EC_SPI_STS_SPI_IDLE_SHIFT))
#define EC_SPI_STS_RX_FIFO_FULL       ((uint8) (0x01u << EC_SPI_STS_RX_FIFO_FULL_SHIFT))
#define EC_SPI_STS_RX_FIFO_NOT_EMPTY  ((uint8) (0x01u << EC_SPI_STS_RX_FIFO_NOT_EMPTY_SHIFT))
#define EC_SPI_STS_RX_FIFO_OVERRUN    ((uint8) (0x01u << EC_SPI_STS_RX_FIFO_OVERRUN_SHIFT))

/* TX and RX masks for clear on read bits */
#define EC_SPI_TX_STS_CLR_ON_RD_BYTES_MASK    (0x09u)
#define EC_SPI_RX_STS_CLR_ON_RD_BYTES_MASK    (0x40u)

/* StatusI Register Interrupt Enable Control Bits */
/* As defined by the Register map for the AUX Control Register */
#define EC_SPI_INT_ENABLE     (0x10u) /* Enable interrupt from statusi */
#define EC_SPI_TX_FIFO_CLR    (0x01u) /* F0 - TX FIFO */
#define EC_SPI_RX_FIFO_CLR    (0x02u) /* F1 - RX FIFO */
#define EC_SPI_FIFO_CLR       (EC_SPI_TX_FIFO_CLR | EC_SPI_RX_FIFO_CLR)

/* Bit Counter (7-bit) Control Register Bit Definitions */
/* As defined by the Register map for the AUX Control Register */
#define EC_SPI_CNTR_ENABLE    (0x20u) /* Enable CNT7 */

/* Bi-Directional mode control bit */
#define EC_SPI_CTRL_TX_SIGNAL_EN  (0x01u)

/* Datapath Auxillary Control Register definitions */
#define EC_SPI_AUX_CTRL_FIFO0_CLR         (0x01u)
#define EC_SPI_AUX_CTRL_FIFO1_CLR         (0x02u)
#define EC_SPI_AUX_CTRL_FIFO0_LVL         (0x04u)
#define EC_SPI_AUX_CTRL_FIFO1_LVL         (0x08u)
#define EC_SPI_STATUS_ACTL_INT_EN_MASK    (0x10u)

/* Component disabled */
#define EC_SPI_DISABLED   (0u)


/***************************************
*       Macros
***************************************/

/* Returns true if componentn enabled */
#define EC_SPI_IS_ENABLED (0u != (EC_SPI_TX_STATUS_ACTL_REG & EC_SPI_INT_ENABLE))

/* Retuns TX status register */
#define EC_SPI_GET_STATUS_TX(swTxSts) ( (uint8)(EC_SPI_TX_STATUS_REG | \
                                                          ((swTxSts) & EC_SPI_TX_STS_CLR_ON_RD_BYTES_MASK)) )
/* Retuns RX status register */
#define EC_SPI_GET_STATUS_RX(swRxSts) ( (uint8)(EC_SPI_RX_STATUS_REG | \
                                                          ((swRxSts) & EC_SPI_RX_STS_CLR_ON_RD_BYTES_MASK)) )


/***************************************
*       Obsolete definitions
***************************************/

/* Following definitions are for version compatibility.
*  They are obsolete in SPIM v2_30.
*  Please do not use it in new projects
*/

#define EC_SPI_WriteByte   EC_SPI_WriteTxData
#define EC_SPI_ReadByte    EC_SPI_ReadRxData
void  EC_SPI_SetInterruptMode(uint8 intSrc)       ;
uint8 EC_SPI_ReadStatus(void)                     ;
void  EC_SPI_EnableInt(void)                      ;
void  EC_SPI_DisableInt(void)                     ;

/* Obsolete register names. Not to be used in new designs */
#define EC_SPI_TXDATA                 (EC_SPI_TXDATA_REG)
#define EC_SPI_RXDATA                 (EC_SPI_RXDATA_REG)
#define EC_SPI_AUX_CONTROLDP0         (EC_SPI_AUX_CONTROL_DP0_REG)
#define EC_SPI_TXBUFFERREAD           (EC_SPI_txBufferRead)
#define EC_SPI_TXBUFFERWRITE          (EC_SPI_txBufferWrite)
#define EC_SPI_RXBUFFERREAD           (EC_SPI_rxBufferRead)
#define EC_SPI_RXBUFFERWRITE          (EC_SPI_rxBufferWrite)

#define EC_SPI_COUNTER_PERIOD         (EC_SPI_COUNTER_PERIOD_REG)
#define EC_SPI_COUNTER_CONTROL        (EC_SPI_COUNTER_CONTROL_REG)
#define EC_SPI_STATUS                 (EC_SPI_TX_STATUS_REG)
#define EC_SPI_CONTROL                (EC_SPI_CONTROL_REG)
#define EC_SPI_STATUS_MASK            (EC_SPI_TX_STATUS_MASK_REG)
#define EC_SPI_STATUS_ACTL            (EC_SPI_TX_STATUS_ACTL_REG)

#define EC_SPI_INIT_INTERRUPTS_MASK  (EC_SPI_INT_ON_SPI_DONE     | \
                                                EC_SPI_INT_ON_TX_EMPTY     | \
                                                EC_SPI_INT_ON_TX_NOT_FULL_DEF  | \
                                                EC_SPI_INT_ON_RX_FULL      | \
                                                EC_SPI_INT_ON_RX_NOT_EMPTY | \
                                                EC_SPI_INT_ON_RX_OVER      | \
                                                EC_SPI_INT_ON_BYTE_COMP)
                                                
/* Following definitions are for version Compatibility.
*  They are obsolete in SPIM v2_40.
*  Please do not use it in new projects
*/

#define EC_SPI_DataWidth                  (EC_SPI_DATA_WIDTH)
#define EC_SPI_InternalClockUsed          (EC_SPI_INTERNAL_CLOCK)
#define EC_SPI_InternalTxInterruptEnabled (EC_SPI_INTERNAL_TX_INT_ENABLED)
#define EC_SPI_InternalRxInterruptEnabled (EC_SPI_INTERNAL_RX_INT_ENABLED)
#define EC_SPI_ModeUseZero                (EC_SPI_MODE_USE_ZERO)
#define EC_SPI_BidirectionalMode          (EC_SPI_BIDIRECTIONAL_MODE)
#define EC_SPI_Mode                       (EC_SPI_MODE)
#define EC_SPI_DATAWIDHT                  (EC_SPI_DATA_WIDTH)
#define EC_SPI_InternalInterruptEnabled   (0u)

#define EC_SPI_TXBUFFERSIZE   (EC_SPI_TX_BUFFER_SIZE)
#define EC_SPI_RXBUFFERSIZE   (EC_SPI_RX_BUFFER_SIZE)

#define EC_SPI_TXBUFFER       EC_SPI_txBuffer
#define EC_SPI_RXBUFFER       EC_SPI_rxBuffer

#endif /* (CY_SPIM_EC_SPI_H) */


/* [] END OF FILE */
